@@ -6,7 +6,7 @@
 # David Hunter <dhunter@stat.psu.edu> and Mark S. Handcock
 # <handcock@u.washington.edu>.
 #
-# Last Modified 8/25/06
+# Last Modified 10/19/06
 # Licensed under the GNU General Public License version 2 (June, 1991)
 #
 # Part of the R/network package
@@ -86,7 +86,7 @@ add.edges<-function(x, tail, head, names.eval=NULL, vals.eval=NULL, ...){
   else if(!is.list(vals.eval))
     vals.eval<-as.list(rep(vals.eval,length=length(names.eval)))
   if(length(unique(c(length(tail),length(head),length(names.eval), length(vals.eval))))>1)
-    error("head, tail, and value lists passed to add.edges must be of the same length!\n")
+    stop("head, tail, and value lists passed to add.edges must be of the same length!\n")
   edge.check<-list(...)$edge.check
   if(is.null(edge.check))
     edge.check<-FALSE
