@@ -126,11 +126,12 @@ g<-rgraph(10)
 temp<-network(g,names.eval="value",ignore.eval=FALSE)
 temp2<-network(g*2,names.eval="value",ignore.eval=FALSE)
 check[54]<-all(g==as.sociomatrix(temp+temp2))
-check[55]<-all(g*3==as.sociomatrix("+"(temp,temp2,"value"),"value"))
+#Note: prior to R 2.4.0, could use "+" instead of "+.network" here...
+check[55]<-all(g*3==as.sociomatrix("+.network"(temp,temp2,"value"),"value"))
 check[56]<-all(g==as.sociomatrix(temp*temp2))
-check[57]<-all(g*2==as.sociomatrix("*"(temp,temp2,"value"),"value"))
+check[57]<-all(g*2==as.sociomatrix("*.network"(temp,temp2,"value"),"value"))
 check[58]<-all(0==as.sociomatrix(temp-temp2))
-check[59]<-all(-g==as.sociomatrix("-"(temp,temp2,"value"),"value"))
+check[59]<-all(-g==as.sociomatrix("-.network"(temp,temp2,"value"),"value"))
 check[60]<-all(((g%*%g)>0)==as.sociomatrix("%c%.network"(temp,temp2)))
 check[61]<-all(((g%*%g)>0)==as.sociomatrix(temp%c%temp2))
 check[62]<-all(((!temp)[,]==!g)[diag(10)<1])
